newChat{ id="welcome",
	text = [[Hello, @playername@. What knowledge do you desire today?]],
	answers = {
		{"I am looking for martial training.", jump="martial"},

		-- no staff training for antimagic characters
		{"I am looking for staff training.", jump="staff", cond=function() return not game.player:attr("forbid_arcane") end},

		-- no mindstar mastery for undead
		-- NOTE: all classes can visit Zigur, you just need to generate the worldmap without having a mana/vim/pos/neg pool,
		-- which can be accomplished by not learning any talents that use them. Undead characters are the only characters that
		-- cannot get mindstar mastery in the normal game (and they don't have much reason to want it, since they can't use any of the talents),
		-- and that is preserved here.
		{"I am looking for mindstar training.", jump="mindstar", cond=function() return not game.player:attr("undead") end},
		{"Sorry, I have to go!"},
	}
}

local trainMsg1 = "Your head tingles as Ansaya's knowledge flows into your mind."
local trainMsg2 = "You feel a sharp pain in your forehead as Ansaya forces knowledge into your mind, but it quickly subsides."
local trainMsg3 = "You get a splitting headache as Ansaya forces knowledge into your mind, but it quickly subsides."

-- Same as the Last Hope shops.
newChat{ id="martial",
	text = [[I can indeed offer some martial training (talent category Technique/Combat-training) for a fee of 50 gold pieces; or the basic usage of bows and slings (Shoot talent) for 8 gold pieces.]],
	answers = {
		{"Please train me in generic weapons and armour usage.", action=function(npc, player)
			game.logPlayer(player, trainMsg1)
			player:incMoney(-50)
			player:learnTalentType("technique/combat-training", true)
			player.changed = true
		end, cond=function(npc, player)
			if player.money < 50 then return end
			if player:knowTalentType("technique/combat-training") then return end
			return true
		end},
		{"Please train me in the basic usage of bows and slings.", action=function(npc, player)
			game.logPlayer(player, trainMsg1)
			player:incMoney(-8)
			player:learnTalent(player.T_SHOOT, true, nil, {no_unlearn=true})
			player.changed = true
		end, cond=function(npc, player)
			if player.money < 8 then return end
			if player:knowTalent(player.T_SHOOT) then return end
			return true
		end},
		{"No thanks."},
	}
}

-- Same as the Angolwen trainer.
newChat{ id="staff",
	text = [[I can teach you staff combat (talent category Spell/Staff combat).  Learning the basics costs 100 gold, while more complete knowledge costs 500 gold.  Once you're proficient, I can teach you more refined techniques for an additional 750 gold.]],
	answers = {
		{"Just give me the basics (reveals locked talent category) - 100 gold.", action=function(npc, player) -- Normal basic training
			game.logPlayer(player, trainMsg1)
			player:incMoney(-100)
			player:learnTalentType("spell/staff-combat", false)
			if player:getTalentTypeMastery("spell/staff-combat") < 1 then
				player:setTalentTypeMastery("spell/staff-combat", math.min(1.1, player:getTalentTypeMastery("spell/staff-combat") + 0.3))
			end
			player.changed = true
		end, cond=function(npc, player)
			if player.money < 100 then return end
			if player:knowTalentType("spell/staff-combat") or player:knowTalentType("spell/staff-combat") == false then return end
			return true
		end},
		{("Please teach me what I need to know (unlocks talent category) - %d gold."):format(500),
		action=function(npc, player) --Normal intensive training
			game.logPlayer(player, trainMsg2)
			player:incMoney(-500)
			player:learnTalentType("spell/staff-combat", true)
			if player:getTalentTypeMastery("spell/staff-combat") < 1 then -- Special case for previously locked category (escort)
				player:setTalentTypeMastery("spell/staff-combat", math.max(1.0, player:getTalentTypeMastery("spell/staff-combat") + 0.3))
			end
			player.changed = true
		end,
		cond=function(npc, player)
			if player.money < 500 then return end
			if player:knowTalentType("spell/staff-combat") then return end
			return true
		end},
		{"I'm already proficient, but I want to be an expert (improves talent mastery by 0.2) - 750 gold.", action=function(npc, player) --Enhanced intensive training
			player:incMoney(-750)
			player:learnTalentType("spell/staff-combat", true)
			player:setTalentTypeMastery("spell/staff-combat", player:getTalentTypeMastery("spell/staff-combat") + 0.2)
			game.logPlayer(player, trainMsg3)
			player.changed = true
		end, cond=function(npc, player)
			if player.money < 750 then return end
			if player:knowTalentType("spell/staff-combat") and player:getTalentTypeMastery("spell/staff-combat") < 1.2 then return true end
		end},
		{"No thanks."},
	}
}

-- Same as the Zigur trainer.
newChat{ id="mindstar",
	text = [[I can teach you mindstar mastery (talent category Wild-gift/Mindstar mastery).  Learning the basics costs 100 gold, while more complete knowledge costs 500 gold.  Once you're proficient, I can teach you some additional skills for 750 gold.]],
	answers = {
		{"Just give me the basics (reveals locked talent category) - 100 gold.", action=function(npc, player) -- Normal basic training
			game.logPlayer(player, trainMsg1)
			player:incMoney(-100)
			player:learnTalentType("wild-gift/mindstar-mastery", false)
			if player:getTalentTypeMastery("wild-gift/mindstar-mastery") < 1 then
				player:setTalentTypeMastery("wild-gift/mindstar-mastery", math.min(1.1, player:getTalentTypeMastery("wild-gift/mindstar-mastery") + 0.3))
			end
			player.changed = true
		end, cond=function(npc, player)
			if player.money < 100 then return end
			if player:knowTalentType("wild-gift/mindstar-mastery") or player:knowTalentType("wild-gift/mindstar-mastery") == false then return end
			return true
		end},
		{"Please teach me what I need to know (unlocks talent category) - 500 gold.", action=function(npc, player)
			game.logPlayer(player, trainMsg2)
			player:incMoney(-500)
			player:learnTalentType("wild-gift/mindstar-mastery", true)
			if player:getTalentTypeMastery("wild-gift/mindstar-mastery") < 1 then -- Special case for previously locked category (escort)
				player:setTalentTypeMastery("wild-gift/mindstar-mastery", math.max(1.0, player:getTalentTypeMastery("wild-gift/mindstar-mastery") + 0.3))
			end
			player.changed = true
		end, cond=function(npc, player)
			if player.money < 500 then return end
			if player:knowTalentType("wild-gift/mindstar-mastery") then return end
			return true
		end},
		{"I'm already proficient, but I want to be an expert (improves talent mastery by 0.2) - 750 gold.", action=function(npc, player) --Enhanced intensive training
			player:incMoney(-750)
			player:learnTalentType("wild-gift/mindstar-mastery", true)
			player:setTalentTypeMastery("wild-gift/mindstar-mastery", player:getTalentTypeMastery("wild-gift/mindstar-mastery") + 0.2)
			game.logPlayer(player, trainMsg3)
			player.changed = true
		end, cond=function(npc, player)
			if player.money < 750 then return end
			if player:knowTalentType("wild-gift/mindstar-mastery") and player:getTalentTypeMastery("wild-gift/mindstar-mastery") < 1.2 then return true end
		end},
		{"No thanks."},
	}
}

return "welcome"
