local function doFileChanges(self,data,fileChangesTable,allFunc)
	local fChanges = fileChangesTable[data.file]
	if fChanges or allFunc then
		for _, obj in pairs(data.res) do
			if type(obj) == "table" then
				if fChanges then
					if fChanges.all then fChanges.all(obj) end
					local oChanges = fChanges[obj.define_as] or fChanges[obj.name]
					if oChanges then
						if oChanges.mut then oChanges.mut(obj) end
						if oChanges.set then
							for key,val in pairs(oChanges.set) do
								obj[key] = val
							end
						end
						if oChanges.remove then
							for _,key in pairs(oChanges.remove) do
								obj[key] = nil
							end
						end
					end
				end
				if allFunc then
					allFunc(obj)
				end
			end
		end
	end
end
local removeEncounter = {set={
	type = "harmless",
	subtype = "special",
	unique = true,
	immediate = {"world-encounter", "maj-eyal"},
	on_encounter = function() return true end,
},
remove = {"rarity","on_world_encounter"}}
local fileChangesTable = {
	["/data/general/objects/quest-artifacts.lua"] = {
		["ROD_OF_RECALL"] = {
			set = {
				use_power = { name = "teleport the user to another zone after 40 turns", power = 1,
					use = function(self, who)
						if who:hasEffect(who.EFF_RECALL) then
							who:removeEffect(who.EFF_RECALL)
							game.logPlayer(who, "The rod emits a strange noise, glows briefly and returns to normal.")
							return {id=true, used=true}
						end
						if not who:attr("never_move") then
							if who:canBe("worldport") then
								who:setEffect(who.EFF_RECALL, 40, {})
								game.logPlayer(who, "Space around you starts to dissolve...")
								return {id=true, used=true}
							elseif game.zone.force_farportal_recall then
								require("engine.ui.Dialog"):yesnoLongPopup("Force a recall", "The Fortress Shadow warned you that trying to force a recall without finding the portal back could break the exploratory farportal forever.", 500, function(ret)
									if not ret then
										who:setEffect(who.EFF_RECALL, 40, { where = "shertul-fortress", allow_override=true })
										game.logPlayer(who, "Space around you starts to dissolve...")
										if rng.percent(90) and who:hasQuest("shertul-fortress") then
											who:hasQuest("shertul-fortress"):break_farportal()
										end
									end
								end, "Cancel", "Recall")
							end
						end
						game.logPlayer(who, "The rod emits a strange noise, glows briefly and returns to normal.")
						return {id=true, used=true}
					end
				},
			},
		},
	},
	["/data/general/encounters/maj-eyal.lua"] = {
		["Sect of Kryl-Faijan"] = removeEncounter, -- Yes, this is misspelled in vanilla.
		["Lost merchant"] = removeEncounter,
	},
}
local exitTele = function(obj)
	if obj.change_zone and obj.change_zone == "wilderness" and not obj.change_level_check then
		-- The game checks if we can enter the worldmap before this is called, so no need to check it again.
		obj.change_level_check = function(self)
			local p = game.party:findMember{main=true}
			if (p:hasQuest("staff-absorption") and not p:hasQuest("staff-absorption"):isCompleted("ambush")) -- force ambush
				or self.change_level_shift_back then -- don't try to teleport when leaving damp caves and similar event zones
				return
			else
				require("engine.Chat").new("qt-recall", {name="Travel"}, p):invoke()
			end
			return true
		end
	end
end

class:bindHook("ToME:load", function(self, data)
	require("engine.interface.ActorTemporaryEffects"):loadDefinition("/data-qt-improved-recall/timed_effects.lua")
end)

class:bindHook("Entity:loadList", function(self, data)
	doFileChanges(self,data,fileChangesTable,exitTele)
end)
