-- version of qt-zone-overhaul
local zoneOverhaulVersion = game.state.qt_zone_overhaul_version or -1
local mergedPrides = zoneOverhaulVersion >= 9

local westCond = function()
	if game.player.descriptor.race == "Yeek" then
		local yq = game.player:hasQuest("start-yeek")
		if yq and not yq:isStatus(yq.DONE) then return false end
	end
	local sq = game.player:hasQuest("start-sunwall")
	if sq and not sq:isCompleted("slazish") then return false end
	return (not game.player:hasQuest("strange-new-world")) or game.player:hasQuest("east-portal") or zoneOverhaulVersion >= 12
end
local yeekCond = function()
	return game.player.descriptor.race == "Yeek" and ((not game.player:hasQuest("strange-new-world")) or game.player:hasQuest("east-portal"))
end
local eastCond = function()
	return (game.player:hasQuest("strange-new-world") and game.player:findInAllInventoriesBy("define_as","ORB_MANY_WAYS") or game.player:findInAllInventoriesBy("define_as","ORB_MANY_WAYS2"))
	or (game.player:hasQuest("start-sunwall") and not game.player:hasQuest("start-sunwall"):isCompleted("slazish"))
end
local qTier1Cond = function(zname)
	if not westCond() then return false end
	if zoneOverhaulVersion >= 4 then
		local q = game.player:hasQuest("qt-tier1-zones")
		return q and (q:isCompleted(zname) or not q:isStatus(q.DONE))
	else
		return true
	end
end
local angolwenCond = function() return (westCond() and game.player:hasQuest("mage-apprentice") and game.player:hasQuest("mage-apprentice"):isStatus(game.player:hasQuest("mage-apprentice").DONE)) or game.player:knowTalent(game.player.T_TELEPORT_ANGOLWEN) end
local orcBridgeCond = function() return game.player:isQuestStatus("orcs+to-mainland",engine.Quest.DONE) end

-- name: The chat option text.
-- sort: Options with lower sort values come before options with higher sort
-- 	values. Options with equal sort values are sorted alphabetically. If omitted, defaults to 0.
-- zone: Zone to change to.
-- wildx: Wilderness x position for the zone (so the player appears there when they go to the worldmap, instead of at the last zone they entered on the worldmap).
-- wildy: Wilderness y position for the zone.
-- dontAdjustWildpos: If dontAdjustWildpos, wilderness position is not changed.
-- cond: If (cond and not cond(zone)), this option won't appear.
-- preChange: preChange() is called before changing zone or setting wilderness position. Return value does nothing.
local zones
if game:isCampaign("Maj'Eyal") then
	zones = {
		-- MISC
		{
			name = "World Map",
			sort = -2,
			zone = "wilderness",
			dontAdjustWildpos = true,
			preChange = function()
				if game.player.level >= 14 and not game.player:hasQuest("lightning-overload") then
					game.player:grantQuest("lightning-overload")
				end
			end,
		},
		{
			name = "Sher-Tul Fortress",
			cond = function() return game.player:hasQuest("shertul-fortress") and game.player:hasQuest("shertul-fortress"):isCompleted("weirdling") end,
			zone = "shertul-fortress",
			dontAdjustWildpos = true,
			sort = -1,
		},

		-- ENCOUNTERS
		{
			name = "Lumberjack Village",
			cond = function() return game.player.level >= 5 and westCond() and not (zoneOverhaulVersion >= 1) end,
			zone = "town-lumberjack-village",
			wildx = 61,
			wildy = 23,
			preChange = function() game.player:grantQuest("lumberjack-cursed") end,
		},
		{
			name = "Thieves' Tunnels",
			cond = function() return game.player.level >= 10 and westCond() and not game.player:hasQuest("lost-merchant") end,
			zone = "thieves-tunnels",
			dontAdjustWildpos = true,
			preChange = function() game.player:grantQuest("lost-merchant") end,
		},
		{
			name = "Crypt of Kryl-Feijan",
			cond = function() return game.player.level >= 24 and westCond() and not game.player:hasQuest("kryl-feijan-escape") end,
			zone = "crypt-kryl-feijan",
			dontAdjustWildpos = true,
			preChange = function() game.player:grantQuest("kryl-feijan-escape") end,
		},

		-- RANDOMLY PLACED ZONES
		{
			name = "Ancient elven ruins",
			cond = function() return westCond() and not (zoneOverhaulVersion >= 12) end,
			zone = "ancient-elven-ruins",
		},
		{
			name = "Golem Graveyard",
			cond = westCond,
			zone = "golem-graveyard",
		},
		{
			name = "Mark of the Spellblaze",
			cond = westCond,
			zone = "mark-spellblaze",
			wildx = 42,
			wildy = 41, -- will change in the future
			-- since this always spawns in basically the same place, we do set wildpos here
		},
		{
			name = "Ruined Dungeon",
			cond = function() return westCond() and not (zoneOverhaulVersion >= 1) end,
			zone = "ruined-dungeon",
		},
		{
			name = "Slavers' Compound",
			cond = function() return westCond() and not (zoneOverhaulVersion >= 1) end,
			zone = "ring-of-blood",
		},
		{
			name = "Flooded Cave",
			cond = function() return eastCond() and not (zoneOverhaulVersion >= 10) end,
			zone = "flooded-cave",
		},
		{
			name = "Shadow Crypt",
			cond = function() return eastCond() and not (zoneOverhaulVersion >= 4) end,
			zone = "shadow-crypt",
		},

		-- TIER 1 ZONES
		{
			name = "The Deep Bellow",
			cond = function() return westCond() and game.player.descriptor.race == "Dwarf"  end,
			zone = "deep-bellow",
			wildx = 70,
			wildy = 23,
		},
		{
			name = "Escape from Reknor",
			cond = function() return westCond() and game.player.descriptor.race == "Dwarf"  end,
			zone = "reknor-escape",
			wildx = 70,
			wildy = 23,
		},
		{
			name = "Heart of the Gloom",
			cond = qTier1Cond,
			zone = "heart-gloom",
			wildx = 44,
			wildy = 15,
		},
		{
			name = "Murgol's Lair",
			cond = yeekCond,
			zone = "murgol-lair",
			wildx = 28,
			wildy = 52,
		},
		{
			name = "Norgos' Lair",
			cond = qTier1Cond,
			zone = "norgos-lair",
			wildx = 36,
			wildy = 13,
		},
		{
			name = "Rhaloren Camp",
			cond = qTier1Cond,
			zone = "rhaloren-camp",
			wildx = 11,
			wildy = 42,
		},
		{
			name = "Ritch Tunnels",
			cond = yeekCond,
			zone = "ritch-tunnels",
			wildx = 38,
			wildy = 48,
		},
		{
			name = "Ruins of Kor'Pul",
			cond = qTier1Cond,
			zone = "ruins-kor-pul",
			wildx = 24,
			wildy = 14,
		},
		{
			name = "Scintillating Caves",
			cond = qTier1Cond,
			zone = "scintillating-caves",
			wildx = 17,
			wildy = 42,
		},
		{
			name = "Trollmire",
			cond = qTier1Cond,
			zone = "trollmire",
			wildx = 28,
			wildy = 13,
		},
		{
			name = "Slazish Fen",
			cond = function() return eastCond() and game.player:hasQuest("start-sunwall") end,
			zone = "slazish-fen",
			wildx = 163,
			wildy = 31,
		},

		-- TIER 2 ZONES
		{
			name = "Daikara",
			cond = westCond,
			zone = "daikara",
			wildx = 58,
			wildy = 11,
		},
		{
			name = "Old Forest",
			cond = westCond,
			zone = "old-forest",
			wildx = 26,
			wildy = 23,
		},
		{
			name = "The Maze",
			cond = westCond,
			zone = "maze",
			wildx = 14,
			wildy = 22,
		},
		{
			name = "Sandworm Lair",
			cond = function() return westCond() and not (zoneOverhaulVersion >= 1) end,
			zone = "sandworm-lair",
			wildx = 4,
			wildy = 24,
		},
		{
			name = "Lake of Nur",
			cond = function() return westCond() and game.player:hasQuest("starter-zones") and game.player:hasQuest("starter-zones"):isCompleted("old-forest") end,
			zone = "lake-nur",
			wildx = 26,
			wildy = 23,
		},

		-- REQUIRED WEST ZONES
		{
			name = "Dreadfell",
			cond = westCond,
			zone = "dreadfell",
			wildx = 50,
			wildy = 44,
		},
		{
			name = "Lost Dwarven Kingdom of Reknor",
			cond = function() return westCond() and game.player:hasQuest("orc-hunt") end,
			zone = "reknor",
			wildx = 69,
			wildy = 22,
		},

		-- MISC OPTIONAL WEST ZONES
		{
			name = "Last Hope's graveyard",
			cond = function() return westCond() and game.player:hasQuest("grave-necromancer") end,
			zone = "last-hope-graveyard",
			wildx = 62,
			wildy = 39,
		},
		{
			name = "Ruined Halfling Complex",
			cond = westCond,
			zone = "halfling-ruins",
			wildx = 37,
			wildy = 32,
		},
		{
			name = "Ruins of Telmur",
			-- it's not currently necessary to check westCond here
			cond = function() return westCond() and game.player:hasQuest("east-portal") and game.player:hasQuest("east-portal"):isCompleted("open-telmur") end,
			zone = "telmur",
			wildx = 52,
			wildy = 29,
		},
		{
			name = "Tempest Peak",
			cond = function() return westCond() and ((zoneOverhaulVersion >= 10) or game.player:hasQuest("lightning-overload") and game.player:hasQuest("lightning-overload"):isCompleted("saved-derth") and (angolwenCond() or game.player:hasQuest("lightning-overload"):isCompleted("tempest-entrance"))) end,
			zone = "tempest-peak",
			wildx = 61,
			wildy = 9,
		},
		{
			name = "Tranquil Meadow",
			cond = function() return westCond() and game.player.descriptor.subclass == "Cursed" end,
			zone = "keepsake-meadow",
			wildx = 54,
			wildy = 20,
		},

		-- REQUIRED EAST ZONES
		{
			name = "Unremarkable Cave",
			cond = function() return eastCond() and zoneOverhaulVersion <= 9 end,
			zone = "unremarkable-cave",
			wildx = 153,
			wildy = 16,
		},
		{
			name = "Slime Tunnels",
			cond = function() return eastCond() and game.player:hasQuest("orc-pride") and game.player:hasQuest("orc-pride"):isCompleted("grushnak") end,
			zone = "slime-tunnels",
			wildx = 132,
			wildy = 10,
		},
		{
			name = "Gorbat Pride",
			cond = function() return (not mergedPrides) and eastCond() and game.player:hasQuest("orc-pride") end,
			zone = "gorbat-pride",
			wildx = 147,
			wildy = 54,
		},
		{
			name = mergedPrides and "Grushbat Pride" or "Grushnak Pride",
			cond = function() return eastCond() and game.player:hasQuest("orc-pride") end,
			zone = "grushnak-pride",
			wildx = 132,
			wildy = 10,
		},
		{
			name = mergedPrides and "Rak'Vor Pride" or "Rak'shor Pride",
			cond = function() return eastCond() and game.player:hasQuest("orc-pride") end,
			zone = "rak-shor-pride",
			wildx = 140,
			wildy = 51,
		},
		{
			name = "Vor Pride",
			cond = function() return (not mergedPrides) and eastCond() and game.player:hasQuest("orc-pride") end,
			zone = "vor-pride",
			wildx = 168,
			wildy = 8,
		},

		-- MISC OPTIONAL EAST ZONES
		{
			name = "Ardhungol",
			cond = function() return eastCond() and game.player:hasQuest("spydric-infestation") end,
			zone = "ardhungol",
			wildx = 162,
			wildy = 28,
		},
		{
			name = "Erúan",
			cond = function() return (not (zoneOverhaulVersion >= 7)) and eastCond() and game.player:hasQuest("pre-charred-scar") end,
			zone = "eruan",
			wildx = 155,
			wildy = 47,
		},
		{
			name = "Vor Armoury",
			cond = function() return eastCond() and game.player:hasQuest("west-portal") end,
			zone = "vor-armoury",
			wildx = 167,
			wildy = 8,
		},
		{
			name = "Briagh's Lair",
			-- allows teleporting there even if you haven't talked to Zemekkys about it, I consider this a plus
			cond = function() return (not (zoneOverhaulVersion >= 5)) and eastCond() and game.player:hasQuest("west-portal") and game.player:hasQuest("west-portal"):isCompleted("athame") end,
			zone = "briagh-lair",
			wildx = 165,
			wildy = 52,
		},
		{
			name = "Caverns leading to the Hidden Valley",
			cond = function() return eastCond() and game.player:hasQuest("master-jeweler") and game.player:hasQuest("master-jeweler"):isCompleted("search-valley") end,
			zone = "valley-moon-caverns",
			wildx = 150,
			wildy = 55,
		},

		-- UNRELIABLE ZONES
		{
			name = "Old Conclave Vault",
			-- because of the fortress library these are actually the only conditions
			cond = function() return westCond() and game.state.can_conclave_vault end,
			zone = "conclave-vault",
			wildx = 47,
			wildy = 34,
		},

		-- TOWNS
		{
			name = "Gates of Morning",
			cond = function() return eastCond() and not (game.player:hasQuest("high-peak") and game.player:hasQuest("high-peak"):isCompleted("gates-of-morning-destroyed")) end,
			zone = "town-gates-of-morning",
			wildx = 163,
			wildy = 31,
		},
		{
			name = "Angolwen",
			cond = angolwenCond,
			zone = "town-angolwen",
			dontAdjustWildpos = true, -- Consistent with the behaviour of the Teleport: Angolwen talent.
		},
		{
			name = "Derth",
			cond = function() return westCond and not (zoneOverhaulVersion >= 10) end,
			zone = "town-derth",
			wildx = 25,
			wildy = 17,
			preChange = function()
				if game.player.level >= 14 and not game.player:hasQuest("lightning-overload") then
					game.player:grantQuest("lightning-overload")
				end
			end,
		},
		{
			name = "Elvala",
			cond = function() return westCond() and not (zoneOverhaulVersion >= 8) end,
			zone = "town-elvala",
			wildx = 15,
			wildy = 44,
		},
		{
			name = "Shatur",
			cond = function() return westCond() and not (zoneOverhaulVersion >= 8) end,
			zone = "town-shatur",
			wildx = 40,
			wildy = 12,
		},
		{
			name = "Irkkk",
			cond = yeekCond,
			zone = "town-irkkk",
			wildx = 27,
			wildy = 49,
		},
		{
			name = "Iron Council",
			cond = function() return westCond() and game.player.descriptor.race == "Dwarf" end,
			zone = "town-iron-council",
			wildx = 70,
			wildy = 23,
		},
		{
			name = "Last Hope",
			cond = westCond,
			zone = "town-last-hope",
			wildx = 60,
			wildy = 39,
		},
		{
			name = "Point Zero",
			cond = function() return game.player:hasQuest("start-point-zero") end,
			zone = "town-point-zero",
			dontAdjustWildpos = true,
		},
		{
			name = "Zigur",
			cond = function() return westCond() and not (game.player:knowTalent(game.player.T_MANA_POOL)
				or game.player:knowTalent(game.player.T_VIM_POOL)
				or game.player:knowTalent(game.player.T_NEGATIVE_POOL)
				or game.player:knowTalent(game.player.T_POSITIVE_POOL)
				or game.player:knowTalent(game.player.T_PARADOX_POOL)
				or game.player:attr("undead"))
			end,
			zone = "town-zigur",
			wildx = 45,
			wildy = 28,
		},
	}
elseif game:isCampaign("Orcs") then
	zones = {
		{
			name = "World Map",
			sort = -2,
			zone = "wilderness",
			dontAdjustWildpos = true,
		},
		{
			name = "Dominion Port",
			cond = function() return orcBridgeCond() and not game.player:isQuestStatus("orcs+kill-dominion",engine.Quest.DONE) end,
			zone = "orcs+dominion-port",
		},
		{
			name = "Gates of Morning",
			cond = orcBridgeCond,
			zone = "orcs+gates-of-morning",
		},
		{
			name = "G.E.M.",
			cond = function() return game.player:isQuestStatus("orcs+destroy-sunwall",engine.Quest.DONE) end,
			zone = "orcs+gem",
		},
		{
			name = "Internment Camp",
			cond = orcBridgeCond,
			zone = "orcs+internment-camp",
		},
		{
			name = "Kaltor's Shop",
			cond = function() return game.player:hasQuest("orcs+kaltor-shop") end,
			zone = "orcs+kaltor-shop",
		},
		{
			name = "Krimbul Territory",
			zone = "orcs+krimbul",
		},
		{
			name = "Erúan Ruins",
			cond = orcBridgeCond,
			zone = "orcs+lost-city",
		},
		{
			name = "Palace of Fumes",
			zone = "orcs+palace-fumes",
		},
		{
			name = "Pocket of Distorted Time",
			cond = orcBridgeCond,
			zone = "orcs+pocket-time",
		},
		{
			name = "Primal Forest",
			cond = orcBridgeCond,
			zone = "orcs+primal-forest",
		},
		{
			name = "Ritch Hive",
			cond = orcBridgeCond,
			zone = "orcs+ritch-hive",
		},
		{
			name = "Steam Quarry",
			zone = "orcs+steam-quarry",
		},
		{
			name = "Sunwall Observatory",
			cond = orcBridgeCond,
			zone = "orcs+sunwall-observatory",
		},
		{
			name = "Sunwall Outpost",
			zone = "orcs+sunwall-outpost",
		},
		{
			name = "Kruk Pride",
			zone = "orcs+town-kruk",
		},
		{
			name = "Ureslak's Host",
			zone = "orcs+ureslak-host",
		},
		{
			name = "Vaporous Emporium",
			zone = "orcs+vaporous-emporium",
		},
		{
			name = "Yeti Caves",
			zone = "orcs+yeti-caves",
		},
	}
end

local function updateWildpos(zone,level)
	local p = game.party:findMember{main=true}
	local z = game.state.qt_recall_zone
	if z then
		game.state.qt_recall_zone = nil

		-- Find zone entrance and put the party there.
		-- If we don't find a zone entrance, we won't move the party.
		for x=0,game.level.map.w-1 do
			for y=0,game.level.map.h-1 do
				local grid = game.level.map:checkAllEntities(x,y,"change_zone")
				if grid == z then
					p.wild_x = x
					p.wild_y = y					
				end
			end
		end
	end
end
local function changeZone(zone,wildx,wildy,preChange,dontAdjustWildpos) return function()
	if preChange then preChange() end
	if not dontAdjustWildpos then
		-- fix for "Never Look Back and There Again" achievement
		if wildx and wildx < 110 then game.state.gone_west = true end

		-- if there is a qt_recall_zone already the onLevelLoad is already present
		if not game.state.qt_recall_zone then game:onLevelLoad("wilderness-1", updateWildpos) end
		-- awful hack, but using upvalues like we do to make this function would introduce
		-- a serialization bug. We get away with it to make this function because it won't ever
		-- need to be serialized (it's part of a chat), but that is not the case for an onLevelLoad
		-- function.
		game.state.qt_recall_zone = zone
	end
	game:changeLevel(1, zone)
end end

local function compareDestinations(dest1,dest2)
	local sort1 = dest1.sort or 0
	local sort2 = dest2.sort or 0
	if sort1 > sort2 then
		return false
	elseif sort1 < sort2 then
		return true
	else
		return string.lower(dest1.name) < string.lower(dest2.name)
	end
end
table.sort(zones,compareDestinations)
local answerList = {
	{"Cancel"},
}
for i,z in pairs(zones) do
	if (not z.cond) or z.cond(z.zone) then
		table.insert(answerList,{z.name,action = changeZone(z.zone,z.wildx,z.wildy,z.preChange,z.dontAdjustWildpos)})
	end
end
newChat{ id="welcome",
	text = [[#WHITE#Where would you like to travel?]],
	answers = answerList,
}

return "welcome"
