-- ToME - Tales of Maj'Eyal
-- Copyright (C) 2009 - 2015 Nicolas Casalini
--
-- This program is free software: you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program.  If not, see <http://www.gnu.org/licenses/>.
--
-- Nicolas Casalini "DarkGod"
-- darkgod@te4.org

-- Yaechs copied from the file that used to be imported here, but revised to
-- give no experience or drops.
local Talents = require("engine.interface.ActorTalents")
-- We don't want uniques to be generated at all here.
local rejectUniques = function(e) return not e.unique end

newEntity{
	define_as = "BASE_NPC_YAECH_NOREWARD",
	type = "humanoid", subtype = "yaech",
	blood_color = colors.BLUE,
	display = "y", color=colors.AQUAMARINE,

	combat = { dam=resolvers.rngavg(5,12), atk=2, apr=6, physspeed=2 },

	body = { INVEN = 10, MAINHAND=1, OFFHAND=1, BODY=1, QUIVER=1 },
	infravision = 10,
	can_breath={water=1},

	life_rating = 9,
	rank = 2,
	size_category = 2,

	open_door = true,

	autolevel = "wildcaster",
	ai = "dumb_talented_simple", ai_state = { ai_move="move_complex", talent_in=1, },
	stats = { str=15, dex=15, mag=15, con=10 },
}

newEntity{ base = "BASE_NPC_YAECH_NOREWARD",
	name = "yaech diver", color=colors.BLUE,
	desc = [[Yaeches are an aquatic subspecies of yeeks. They share the same psionic powers, but they refuse to take part in the Way.]],
	level_range = {1, nil}, exp_worth = 0,
	rarity = 1,
	max_life = resolvers.rngavg(50,70),
	resolvers.equip{
		{type="weapon", subtype="trident", autoreq=true, special_rarity="trident_rarity", never_drop=true, special = rejectUniques},
	},
	resolvers.talents{
		[Talents.T_KINETIC_SHIELD]={base=1, every=15, max=3},
		[Talents.T_EXOTIC_WEAPONS_MASTERY]={base=1, every=10, max=5},
	},
}

newEntity{ base = "BASE_NPC_YAECH_NOREWARD",
	name = "yaech hunter", color=colors.UMBER,
	desc = [[Yaeches are an aquatic subspecies of yeeks. They share the same psionic powers, but they refuse to take part in the Way.]],
	level_range = {1, nil}, exp_worth = 0,
	rarity = 2,
	max_life = resolvers.rngavg(90,110),
	resolvers.equip{
		{type="weapon", subtype="trident", autoreq=true, special_rarity="trident_rarity", never_drop=true, special = rejectUniques},
	},
	resolvers.talents{
		[Talents.T_EXOTIC_WEAPONS_MASTERY]={base=1, every=10, max=5},
		[Talents.T_MINDHOOK]={base=1, every=7, max=5},
		[Talents.T_PERFECT_CONTROL]={base=2, every=7, max=5},
	},
}

newEntity{ base = "BASE_NPC_YAECH_NOREWARD",
	name = "yaech mindslayer", color=colors.YELLOW,
	desc = [[Yaeches are an aquatic subspecies of yeeks. They share the same psionic powers, but they refuse to take part in the Way.]],
	level_range = {2, nil}, exp_worth = 0,
	rarity = 2,
	max_life = resolvers.rngavg(90,110),
	resolvers.equip{
		{type="weapon", subtype="trident", autoreq=true, special_rarity="trident_rarity", never_drop=true, special = rejectUniques},
	},
	resolvers.talents{
		[Talents.T_KINETIC_AURA]={base=1, every=7, max=5},
		[Talents.T_CHARGED_AURA]={base=1, every=7, max=5},
		[Talents.T_KINETIC_SHIELD]={base=2, every=7, max=5},
		[Talents.T_EXOTIC_WEAPONS_MASTERY]={base=1, every=10, max=5},
	},
}

newEntity{ base = "BASE_NPC_YAECH_NOREWARD",
	name = "yaech psion", color=colors.RED,
	desc = [[Yaeches are an aquatic subspecies of yeeks. They share the same psionic powers, but they refuse to take part in the Way.]],
	level_range = {3, nil}, exp_worth = 0,
	rarity = 3,
	max_life = resolvers.rngavg(80,90),
	resolvers.equip{
		{type="weapon", subtype="trident", autoreq=true, special_rarity="trident_rarity", never_drop=true, special = rejectUniques},
	},
	resolvers.talents{
		[Talents.T_PYROKINESIS]={base=2, every=7, max=5},
		[Talents.T_MINDLASH]={base=1, every=7, max=5},
	},
}

newEntity{
	name = "Melinda", define_as = "MELINDA_BEACH",
	type = "humanoid", subtype = "human", female=true,
	display = "@", color=colors.LIGHT_BLUE,
	image = "player/cornac_female_redhair.png",
	moddable_tile = "human_female",
	moddable_tile_base = "base_redhead_01.png",
	desc = [[Enjoying a lovely day at the beach.]],
	autolevel = "tank",
	ai = "move_complex", ai_state = { ai_target="target_player", talent_in=4, },
	stats = { str=8, dex=7, mag=8, con=12 },
	level_range = {10, 10},
	faction = "allied-kingdoms",
	never_anger = true,
	resists = {all=86},

	moddable_tile_nude = 1,
	moddable_tile_ornament = {female="braid_redhead_01"},
	resolvers.equip{ id=true,
		{defined="MELINDA_BIKINI", autoreq=true, ego_chance=-1000}
	},

	body = { INVEN = 10, MAINHAND=1, OFFHAND=1, BODY=1, QUIVER=1 },
	lite = 4,
	rank = 2,
	exp_worth = 0,

	max_life = 100, life_regen = 0,
	life_rating = 45,
	combat_armor = 3, combat_def = 3,

	on_resurrect = function(self)
		game.level.data.blight_start_in = nil
		game.level.map:particleEmitter(self.x, self.y, 10, "ball_blight", {radius=10})
		local list = {}
		for uid, e in pairs(game.level.entities) do
			if e.type == "humanoid" and e.subtype == "yaech" then list[#list+1] = e end
		end
		for _, e in ipairs(list) do
			local DamageType = require "engine.DamageType"
			DamageType:get(DamageType.BLIGHT).projector(self, e.x, e.y, DamageType.BLIGHT, 10000)
		end
		self:doEmote("What..! Please lets run!", 120)
		game.player:setQuestStatus("love-melinda", engine.Quest.COMPLETED, "saved-beach")
		game.bignews:say(120, "#DARK_GREEN#As Melinda is about to die a powerful wave of blight emanates from her!")
	end,

	on_die = function(self)
		game.player:setQuestStatus("love-melinda", engine.Quest.COMPLETED, "death-beach")
		game.player:setQuestStatus("love-melinda", engine.Quest.FAILED)
	end,
}
