local DamageType = require "engine.DamageType"
local ActorTalents = require("engine.interface.ActorTalents")
local function doTalentChanges(changes)
	for talentId,changes in pairs(changes) do
		local talent = Talents.talents_def[talentId]
		if talent then -- Ashes of Urh'Rok talents etc. might not exist
			if changes.mut then changes.mut(talent) end
			if changes.set then
				for key,val in pairs(changes.set) do
					talent[key] = val
				end
			end
			if changes.remove then
				for _,key in pairs(changes.remove) do
					talent[key] = nil
				end
			end
		end
	end
end
local function radianceRadius(self)
	if self:hasEffect(self.EFF_RADIANCE_DIM) then
		return 1
	else
		return self:getTalentRadius(self:getTalentFromId(self.T_RADIANCE))
	end
end

local damDesc = ActorTalents.damDesc

-- Talents we notably DON'T buff at the moment even though they give see invis/stealth/light:
-- Vigilance
-- Heightened Senses
-- Piercing Sight
-- Preternatural Senses
-- Chant of Light
-- Sun Flare
-- That fire arrow talent
local function makeChanges()
local noNpc = {set={no_npc_use=true, not_on_random_boss=true}}
local talentChangesTable = {
--	["T_KEEN_SENSES"] = { -- Increase critical chance to compensate for see invis/stealth being essentially useless to players
--		set = {getCriticalChance = function(self, t) return self:combatTalentSpellDamage(t, 4, 24) end}
--	},
	["T_ILLUMINATE"] = { -- The illumination part is no longer useful, so start the damage at level 1.
		set = {
			tactical = { DISABLE = 2, ATTACKAREA = { LIGHT = 2 }},
			action = function(self, t)
				local tg = self:getTalentTarget(t)
				game.level.map:particleEmitter(self.x, self.y, tg.radius, "sunburst", {radius=tg.radius, grids=grids, tx=self.x, ty=self.y, max_alpha=80})
				if self:getTalentLevel(t) >= 3 then
					self:project(tg, self.x, self.y, DamageType.BLIND, t.getBlindPower(self, t))
				end
				self:project(tg, self.x, self.y, DamageType.LIGHT, self:spellCrit(t.getDamage(self, t)))
				game:playSoundNear(self, "talents/heal")
				return true
			end,
			info = function(self, t)
				local radius = self:getTalentRadius(t)
				local turn = t.getBlindPower(self, t)
				local dam = t.getDamage(self, t)
				return ([[Creates a globe of pure light within a radius of %d that deals %0.2f light damage.
At level 3, it also blinds all who see it (except the caster) for %d turns.]]):
				format(radius, damDesc(self, DamageType.LIGHT, dam), turn)
			end,
		},
	},
	["T_INVISIBILITY"] = noNpc,
--	["T_SECRETS_OF_THE_ETERNALS"] = noNpc, -- Doesn't reduce damage, so it's fine for NPCs to use it. (And this wouldn't stop them from starting with it sustained, anyway)
	["T_OVERSEER_OF_NATIONS"] = { -- 
		set = {
			-- same as confusion immunity for now
			getRes = function(self, t) return self:combatTalentLimit(t, 100, 10, 40) end,
			passives = function(self, t, p)
				self:talentTemporaryValue(p, "confusion_immune", t.getImmune(self, t))
				self:talentTemporaryValue(p, "resists", {[DamageType.LIGHT] = t.getRes(self, t),[DamageType.DARKNESS] = t.getRes(self, t)})
			end,
			info = function(self, t)
				return ([[While Highers are not meant to rule other humans - and show no particular will to do so - they are frequently called to higher duties.
Their nature grants them better senses than other humans.
Increase confusion immunity by %d%%, and light and darkness resistances by %d%%.]]):
				format(t.getImmune(self, t) * 100, t.getRes(self, t))
			end,
		},
	},
	-- Finally some actives. Also, inscription code is dumb.
	["T_RUNE:_INVISIBILITY_1"] = noNpc,
	["T_RUNE:_INVISIBILITY_2"] = noNpc,
	["T_RUNE:_INVISIBILITY_3"] = noNpc,
	["T_RUNE:_INVISIBILITY_4"] = noNpc,
	["T_RUNE:_INVISIBILITY_5"] = noNpc,
	["T_RUNE:_INVISIBILITY_6"] = noNpc,
	["T_INFUSION:_SUN_1"] = noNpc,
	["T_INFUSION:_SUN_2"] = noNpc,
	["T_INFUSION:_SUN_3"] = noNpc,
	["T_INFUSION:_SUN_4"] = noNpc,
	["T_INFUSION:_SUN_5"] = noNpc,
	["T_INFUSION:_SUN_6"] = noNpc,
--	This talent is gone anyway
--	["T_MOMENT_OF_PRESCIENCE"] = { -- Increase accuracy/defense to compensate for see invis/stealth being essentially useless to players
--		set = {getPower = function(self, t) return self:combatTalentScale(t, 8, 30) end}
--	},
	["T_RADIANCE"] = { -- Replace blindness immunity with confusion immunity.
		set = {
			passives = function(self, t, p)
				self:talentTemporaryValue(p, "radiance_aura", radianceRadius(self))
				self:talentTemporaryValue(p, "confusion_immune", t.getResist(self, t) / 100)
			end,
			info = function(self, t)
				return ([[You are so infused with sunlight that your body glows permanently in radius %d.
This glow keeps your mind clear, giving you %d%% confusion resistance.]]):
				format(radianceRadius(self), t.getResist(self, t))
			end,
		},
	},
	["T_ILLUMINATION"] = { -- Increase defense penalty to compensate for see invis/stealth being essentially useless to players
		set = {
			getDef = function(self, t) return 5 + self:combatTalentSpellDamage(t, 2, 70) end,
		},
	},
--[=[	["T_HYMN_OF_DETECTION"] = { -- is now hymn of spellcrit (and still probably garbage)
		set = {
			getSpellCrit = function(self, t) return self:combatTalentSpellDamage(t, 3, 18) end,
			activate = function(self, t)
				game:playSoundNear(self, "talents/spell_generic2")
				local ret = {
					onhit = self:addTemporaryValue("on_melee_hit", {[DamageType.DARKNESS]= t.getDamageOnMeleeHit(self, t)}),
					invis = self:addTemporaryValue("see_invisible", t.getSeeInvisible(self, t)),
					stealth = self:addTemporaryValue("see_stealth", t.getSeeStealth(self, t)),
					crit = self:addTemporaryValue("combat_spellcrit", t.getSpellCrit(self, t)),
					particle = self:addParticles(Particles.new("darkness_shield", 1))
				}
				return ret
			end,
			deactivate = function(self, t, p)
				self:removeParticles(p.particle)
				self:removeTemporaryValue("on_melee_hit", p.onhit)
				self:removeTemporaryValue("combat_spellcrit", p.crit)
				self:removeTemporaryValue("see_invisible", p.invis)
				self:removeTemporaryValue("see_stealth", p.stealth)
				return true
			end,
			info = function(self, t)
				local crit = t.getSpellCrit(self, t)
				local invis = t.getSeeInvisible(self, t)
				local stealth = t.getSeeStealth(self, t)
				local darknessdamage = t.getDamageOnMeleeHit(self, t)
				return ([[Chant the glory of the Moon, granting you +%d%% spell critical chance, stealth detection (+%d power), and invisibility detection (+%d power).
In addition, this talent surrounds you with a shield of shadows, dealing %0.2f darkness damage to anything that attacks you.
You may only have one Hymn active at once.
The spell critical chance, stealth detection, and invisibility detection, as well as the on-hit damage, will increase with your Spellpower.]]):
				format(crit, stealth, invis, damDesc(self, DamageType.DARKNESS, darknessdamage))
			end,
		},
	},]=]
	["T_HEIGHTENED_SENSES"] = { -- NOTE: we're going to remove traps in the future, probably change this to defense or remove the tree (this talent is certainly useless atm)
		set = {
			info = function(self, t)
				return ([[Your attention to detail increases stealth detection and invisibility detection by %d, and you gain the ability to detect traps (+%d detect 'power').
The detection abilities improve with Cunning.]]):
				format(t.seePower(self,t),t.trapDetect(self,t))
			end,
		},
	},
	["T_ARMOUR_OF_SHADOWS"] = { -- Remove the light gimmick.
		set = {
			info = function(self, t)
				return ([[You know how to protect yourself with the deepest shadows. You gain %d armour and 50%% armour hardiness.
The armor bonus scales with your Constitution.]])
				:format(t.ArmourBonus(self,t))
			end,
		},
		remove = {"on_learn","on_unlearn"},
	},
	["T_WORLDLY_KNOWLEDGE"] = { -- Adjust description for different categories (chat overload handles the rest).
		set = {
			info = function(self, t)
				return ([[
Learn a new talent category from one of the below at 0.9 mastery, unlocked. Group 1 categories are available to anyone; Group 2 are available only to people without any spells or runes, and Group 3 are not available to followers of Zigur.
GROUP 1:
- Technique / Conditioning
- Technique / Acrobatics
GROUP 2:
- Technique / Mobility
- Technique / Field Control
- Wild Gift / Call of the Wild
- Wild Gift / Mindstar Mastery
- Psionic / Dreaming
GROUP 3:
- Spell / Conveyance
- Spell / Staff Combat
- Spell / Stone Alchemy
- Celestial / Chants
- Celestial / Light
- Chronomancy / Chronomancy]]):format()
			end,
		},
	},
	["T_VIMSENSE"] = { -- Heavily changed talent: instead of detecting creatures, inflicts the Vimsense debuff on all hostile creatures within sight radius,
			-- and does so like most of Defilers' other debuffs: can be saved against (nerf), but can also spellshock (buff). No longer makes the creatures
			-- target the player. Overall the debuff is probably less useful than before since not only can it be saved against, it can no longer be used
			-- to debuff creatures that are out of LOS around a corner or something. But that's good, we want to nerf things like that. And it's still
			-- better than Curse of Vulnerability!
		set = {
			direct_hit = true,
			requires_target = true,
			range = 0,
			radius = 10,
			target = function(self, t)
				return {type="ball", range=self:getTalentRange(t), radius=self:getTalentRadius(t), selffire=false, talent=t}
			end,
			info = function(self, t)
				return ([[
Touch the life force of all hostile creatures in a radius of 10, reducing their blight resistance by %d%% for %d turns.
The resistance reduction will improve with your Spellpower.]]):
				format(t.getResistPenalty(self,t), t.getDuration(self,t))
			end,
			action = function(self, t)
				local tg = self:getTalentTarget(t)
				self:project(tg, self.x, self.y, function(tx, ty)
					local target = game.level.map(tx, ty, Map.ACTOR)
					if not target or target == self or self:reactionToward(target) >= 0 then return end
					target:setEffect(target.EFF_VIMSENSE, t.getDuration(self,t), {power=t.getResistPenalty(self,t), apply_power=self:combatSpellpower()})
				end)
				game:playSoundNear(self, "talents/spell_generic")
				return true
			end,
		},
	},
	["T_DARKNESS"] = { -- Remove.
		set = {
			no_npc_use = true,
			hide = "always",
			action = function(self, t)
				return true
			end,
		},
	},
	["T_TRACK"] = { -- Remove.
		set = {
			type = {"other/other",1},
			no_npc_use = true,
			hide = "always",
			action = function(self, t)
				return true
			end,
		},
	},
	["T_PRETERNATURAL_SENSES"] = {
		set = {
			-- consistent with the way defense and crit scales on many other talents, believe it or not
			-- both of these are called in superloads; the "passives" field only updates values when a sustained talent would, therefore
			-- using it would result in a talent that is broken the same way most of the game's sustains are currently broken.
			getDefense = function(self, t) return self:combatScale(self:getTalentLevel(t)*self:combatMindpower(), 0, 0, 25, 300, 0.75) end,
			getCriticalChance = function(self, t) return self:combatTalentMindDamage(t, 2, 12) end,
			info = function(self, t)
				local def = t.getDefense(self, t)
				local crit = t.getCriticalChance(self, t)
				local sense = t.sensePower(self, t)
				return ([[Your preternatural senses aid you in your hunt for the next victim. Improves your Defense by %d and your physical and mental critical chance by %0.1f%%.
Also increases stealth detection by %d and invisibility detection by %d.
The effects will improve with your Mindpower.]]):
				format(def, crit, sense, sense)
			end,
		},
	},
	["T_SHADOW_SENSES"] = {
		set = {
			-- We can use passives for this one though.
			getRes = function(self, t) return self:combatTalentScale(t, 8, 32, 0.75, 0, 0, false) end,
			passives = function(self, t, p)
				self:talentTemporaryValue(p, "resist_unseen", t.getRes(self, t))
			end,
			info = function(self, t)
				local res = t.getRes(self, t)
				return ([[You have a vague awareness of foes even when you cannot see them.
All damage from unseen attackers is reduced by %0.1f%%.]]):
				format(res)
			end,
		},
	},
	["T_THOUGHT_SENSE"] = {
		set = {
			-- handled in superload
			mode = "passive",
			info = function(self, t)
				local def = t.getDefense(self, t)
				return ([[You read the surface thoughts of your opponents to predict their attacks, increasing your Defense by %d.]]):
				format(def)
			end,
		},
		remove = {"psi","cooldown","tactical","action"},
	},
	["T_EARTH_S_EYES"] = {
		set = {
			getSaves = function(self, t) return self:getTalentLevel(t) * 5 end,
			mode = "passive",
			passives = function(self, t, p)
				self:talentTemporaryValue(p, "combat_spellresist", t.getSaves(self,t))
				self:talentTemporaryValue(p, "combat_physresist", t.getSaves(self,t))
			end,
			info = function(self, t)
				local sv = t.getSaves(self, t)
				return ([[Your connection to Nature gives you keen senses, increasing your physical and spell saves by %d.]]):
				format(sv)
			end,
		},
		remove = {"equilibrium","cooldown","tactical","action","requires_target","no_npc_use"},
	},
	["T_PRECOGNITION"] = {
		set = {
			getAccuracy = function(self, t) return self:combatTalentStatDamage(t, "mag", 10, 50) end,
			getPhysCrit = function(self, t) return self:combatTalentStatDamage(t, "mag", 2, 10) end,
			action = function(self, t)
				-- Foresight bonuses
				local defense = 0
				local crits = 0
				if self:knowTalent(self.T_FORESIGHT) then
					defense = self:callTalent(self.T_FORESIGHT, "getDefense")
					crits = self:callTalent(self.T_FORESIGHT, "getCritDefense")
				end
				local acc = t.getAccuracy(self,t)
				local physcrit = t.getPhysCrit(self,t)
				-- we edit this timed effect in the load hook
				self:setEffect(self.EFF_PRECOGNITION, t.getDuration(self, t), {range=self:getTalentRange(t), actor=1, traps=1, defense=defense, crits=crits, accuracy=acc, physcrit=physcrit})
		
				return true
			end,
			info = function(self, t)
				local acc = t.getAccuracy(self, t)
				local physcrit = t.getPhysCrit(self, t)
				local duration = t.getDuration(self, t)
				return ([[You peer into the future, gaining %d Accuracy and %d%% physical critical chance for %d turns. These bonuses scale with your Magic stat.
If you know Foresight you'll gain additional defense and chance to shrug off critical hits (equal to your Foresight bonuses) while Precognition is active.]]):format(acc, physcrit, duration)
			end,
		},
		remove = {"range"},
	},
	-- We don't actually remove the esp because it doesn't do anything anyway and that lets us leave several fields alone. We just remove it from the description.
	["T_MIND_LINK"] = {
		set = {
			info = function(self, t)
				local damage = t.getBonusDamage(self, t)
				local range = self:getTalentRange(t) * 2
				return ([[Link minds with the target.  While your minds are linked, you'll inflict %d%% more mind damage to the target.
Only one mindlink can be maintained at a time, and the effect will break if the target dies or goes beyond range (%d)).
The mind damage bonus will scale with your Mindpower.]]):format(damage, range)
			end,
		},
	},
	-- Ashes of Urh'Rok talents
	-- This one is awful, but then, so is its original design...got rid of the light stuff but halved the damage increase.
	["T_DEMON_SEED_CORRUPT_LIGHT"] = {
		set = {
			action = function(self, t)
				local tg = self:getTalentTarget(t)
				local x, y = self:getTarget(tg)
				if not x or not y then return nil end
				local nb = 0
				self:project(tg, x, y, function(px, py)
					nb = nb + 1
				end, nil, {type="dark"})
				if nb > 0 then
					local power = math.sqrt(nb) * 3
					self:setEffect(self.EFF_DEMON_SEED_CORRUPT_LIGHT, 5, {power=power})
				end
				self:move(self.x, self.y, true)
				game:playSoundNear(self, "talents/breath")
				return true
			end,
			info = function(self, t)
				return ([[Weave darkness in a radius of %d. Every grid reached by the darkness contributes to your power by increasing all your damage done for %d turns.
Damage increase depends on the number of grids reached.]]):
				format(self:getTalentRadius(t), t.getDuration(self, t))
			end,
		},
	},
	["T_DEMON_SEED_SHADOWMELD"] = {
		set = {
			info = function(self, t)
				return ([[You meld with the shadows, gaining %d stealth power. Moving will cancel the effect.
Stealth power depends on Spellpower.]]):
				format(t.getStealth(self, t))
			end,		
		},
		remove = {"on_pre_use"}, -- yeah this allows getting it with Morrigor via doomed shade, or by alchemist golem and sacrificing a life, or whatever. who cares
	},
}
doTalentChanges(talentChangesTable)

-- EVEN MORE HORRENDOUS HACK THAN EVERYTHING ABOVE! THIS IS ME MUTILATING
-- ENCAPSULATION'S CORPSE THEN USING A SPACE CANNON TO LAUNCH IT INTO THE SUN!
-- (YOU HAVE TO USE A SPACE CANNON, A REGULAR CANNON ISN'T POWERFUL ENOUGH)
ActorTalents.talents_types_def["technique/field-control"].talents[2] = ActorTalents.talents_def.T_EVASION

end

makeChanges()
