local _M = loadPrevious(...)

local Map = require "engine.Map"
local Dialog = require "engine.ui.Dialog"
local ActorTalents = require "engine.interface.ActorTalents"

-- Precompute FOV form, for speed
local fovdist = {}
for i = 0, 30 * 30 do
	fovdist[i] = math.max((20 - math.sqrt(i)) / 17, 0.6)
end
local wild_fovdist = {}
for i = 0, 10 * 10 do
	wild_fovdist[i] = math.max((5 - math.sqrt(i)) / 1.4, 0.6)
end
-- OVERWRITE playerFOV(), not calling the original. I don't think there's a better way.
-- Note, this is called for whatever the current player-controlled entity is.
function _M:playerFOV()
	-- Clean FOV before computing it
	game.level.map:cleanFOV()

	-- Do wilderness stuff, nothing else
	if game.zone.wilderness then
		self:computeFOV(game.zone.wilderness_see_radius, "block_sight", function(x, y, dx, dy, sqdist) game.level.map:applyLite(x, y, wild_fovdist[sqdist]) end, true, true, true)
		return
	end

	-- First QuickTome change: ESP, Sense, Arcane Eye, Preternatural Senses, and Shadow Senses are OBLITERATED.
	-- Second QuickTome change: blindness doesn't block sight for the player-controlled entity.

	-- Handle dark vision; same as infravision, but also sees past creeping dark
	-- this is treated as a sense, but is filtered by custom LOS code
	if self:knowTalent(self.T_DARK_VISION) then
		local t = self:getTalentFromId(self.T_DARK_VISION)
		local range = self:getTalentRange(t)
		self:computeFOV(range, "block_sense", function(x, y)
			local actor = game.level.map(x, y, game.level.map.ACTOR)
			if actor and self:hasLOS(x, y) then
				game.level.map.seens(x, y, 0.6)
			end
		end, true, true, true)
	end

	-- Second QuickTome change: Sight is locked at 10
	-- No need to compute FOV twice or apply extra light from entities. Well, at least I think so...
	self:computeFOV(10, "block_sight", function(x, y, dx, dy, sqdist)
		game.level.map:apply(x, y, fovdist[sqdist])
		game.level.map:applyLite(x, y)
	end, true, false, true)
end

return _M
