local function doFileChanges(self,data,fileChangesTable)
	local fChanges = fileChangesTable[data.file]
	if fChanges then
		for _, obj in pairs(data.res) do
			if fChanges.all then fChanges.all(obj) end
			local oChanges = fChanges[obj.define_as] or fChanges[obj.name]
			if oChanges then
				if oChanges.mut then oChanges.mut(obj) end
				if oChanges.set then
					for key,val in pairs(oChanges.set) do
						obj[key] = val
					end
				end
				if oChanges.remove then
					for _,key in pairs(oChanges.remove) do
						obj[key] = nil
					end
				end
			end
		end
	end
end
-- Format:
-- [filename] = {
--   all = function(object),
--
--   [entity define_as OR entity name] = {
--     mut = function(object),
--     set = {
--       [field name] = {value},
--     },
--     remove = {
--       "[field name]"
--     },
--   },
-- }
--
-- The define_as takes precedence over the name, so if you have entries
-- for both ["ROGUE_PLIGHT"] and ["Rogue Plight"] only the first one
-- will be used.
--
-- all is an arbitrary function to run on every object. we're assuming
-- nobody is going to define an entity named "all"
--
-- mut is an arbitrary function to run with the object as its only
-- parameter, nice if you want to change a field in the entity without
-- overwriting it
--
-- set simply sets the entity's field to the value.
--
-- remove will set all the fields specified to nil.
--
-- All of these fields are optional.
--
-- The all function is run first, then the mut function, then set, then
-- remove.
--
-- example:
-- ["/data/general/objects/world-artifacts.lua"] = {
--   ["Summertide Phial"] = {
--     mut = function(obj) obj.wielder.lite = nil end,
--     set = {
--       encumber = 0.5,
--       cost = 100,
--     }
--     remove = { "max_power", "power_regen", "use_power" }
--   },
-- },
--
-- Q: Why do you allow using both the define_as and the name? Shouldn't you just use the name?
-- A: Many objects, such as Summertide Phial, actually lack a define_as. And many objects, such as most base NPCs, lack a name.
--    Objects that lack both, however, pretty much don't exist. And overlap between the fields is extremely unlikely.
local killTrap = {all = function(obj)
	obj.on_added = function(self, level, x, y)
		game.level.map:remove(x, y, require("engine.Map").TRAP) -- remove trap immediately after it's added
	end
end}

local fileChangesTable = {
	["/data/general/traps/alarm.lua"] = killTrap,
	["/data/general/traps/annoy.lua"] = killTrap,
	["/data/general/traps/complex.lua"] = killTrap,
	["/data/general/traps/elemental.lua"] = killTrap,
	["/data/general/traps/natural_forest.lua"] = killTrap,
	["/data/general/traps/teleport.lua"] = killTrap,
	["/data/general/traps/temporal.lua"] = killTrap,
	["/data/general/traps/water.lua"] = killTrap,
}

class:bindHook("Entity:loadList", function(self, data)
	doFileChanges(self,data,fileChangesTable)
end)
