local DamageType = require "engine.DamageType"
local Talents = require("engine.interface.ActorTalents")
local Stats = require "engine.interface.ActorStats"
local function doTalentChanges(changes)
	for talentId,changes in pairs(changes) do
		local talent = Talents.talents_def[talentId]
		if talent then -- Ashes of Urh'Rok talents etc. might not exist
			if changes.mut then changes.mut(talent) end
			if changes.set then
				for key,val in pairs(changes.set) do
					talent[key] = val
				end
			end
			if changes.remove then
				for _,key in pairs(changes.remove) do
					talent[key] = nil
				end
			end
		end
	end
end
local function makeChanges()

local talentChangesTable = {
	["T_LEGACY_OF_THE_NALOREN"] = {
		set = {
			on_learn = function(self, t)
				local o = mod.class.Object.new{
					slot = "MAINHAND",
					slot_forbid = "OFFHAND",
					type = "weapon", subtype="trident",
					moddable_tile = resolvers.moddable_tile("trident"),
					add_name = " (#COMBAT#)",
					display = "|", color=colors.AQUAMARINE,
					power_source = {nature=true, psionic=true},
					define_as = "LEGACY_NALOREN",
					unided_name = "ornate orichalcum trident",
					name = "Legacy of the Naloren", unique=true, image = "object/artifact/legacy_of_the_naloren.png",
					desc = [[This incredibly beautiful -- and powerful -- trident is made of the rare metal orichalcum. An amazing pearl is seated in head of the trident, as it spreads into three razor sharp prongs.
				It is imbued with the greatest strengths of all of the most powerful Naga warriors.
				Slasul gave it to you as a sign of his faith in you. It is a sign of hope for all of the Naloren race, that one outside of their tribe could be so trusted.]],
					require = { stat = { str=35 }, },
					level_range = {40, 50},
					rarity = false,
					cost = 350,
					material_level = 5,
					plot = true,
					encumber = 3,
					metallic = true,
					no_rust = true,
					combat = {
						talented = "trident",
						accuracy_effect = "mace",
						damrange = 1.6,
						physspeed = 1,
						sound = {"actions/melee", pitch=0.6, vol=1.2},
						sound_miss = {"actions/melee", pitch=0.6, vol=1.2},
						dam = 84,
						apr = 20,
						physcrit = 20,
						dammod = {str=1.4},
						damrange = 1.4,
						talent_on_hit = { T_STUNNING_BLOW = {level=1, chance=10}, T_SILENCE = {level=3, chance=10}, T_SPIT_POISON = {level=5, chance=10} }
					},

					wielder = {
						lite = 2,
						combat_dam = 12,
						combat_mindpower = 12,
						combat_mindcrit = 12,
						inc_stats = {
							[Stats.STAT_STR] = 4,
							[Stats.STAT_DEX] = 4,
							[Stats.STAT_MAG] = 4,
							[Stats.STAT_WIL] = 4,
							[Stats.STAT_CUN] = 4,
							[Stats.STAT_CON] = 4,
							[Stats.STAT_LCK] = 10,
						},
						resists = {
							[DamageType.COLD] = 15,
							[DamageType.NATURE] = 20,
							[DamageType.ACID] = 10,
						},
						inc_damage = {
							[DamageType.COLD] = 15,
							[DamageType.NATURE] = 25,
							[DamageType.MIND] = 10,
						},
						talent_cd_reduction={
							[Talents.T_RUSH]=3,
							[Talents.T_SPIT_POISON]=2,
						},
						talents_types_mastery = {
							["technique/combat-training"] = 0.3,
							["technique/combat-techniques-active"] = 0.3,
							["psionic/psychic-assault"] = 0.3,
						},
					},

					max_power = 60, power_regen = 1,
					use_talent = { id = Talents.T_IMPLODE, level=2, power = 40 },
				}
				o:resolve() o:resolve(nil, true)
				o:identify(true)
				self:addObject(self.INVEN_INVEN, o)
			end,
			info = function(self, t)
				local level = t.bonusLevel(self,t)
				return ([[You have sided with the Naloren race. You are now able to breathe underwater with ease.
You have also learned to use tridents and other exotic weapons easily (talent level %d of Exotic Weapon Mastery), and can Spit Poison (talent level %d) as nagas do. These are bonus talent levels that increase with your character level.
In addition, you will recieve a powerful trident upon learning this prodigy.]])
				:format(level, level)
			end,
		},
		mut = function(talent)
			if talent.require then talent.require.special=nil end
		end,
	},
}
doTalentChanges(talentChangesTable)

end

makeChanges()
