class:bindHook("ToME:load", function(self, data)
	-- increase gold found on the ground
	local Birther = require("engine.Birther")
	local desc = Birther:getBirthDescriptor("world","Maj'Eyal")
	if desc.copy then
		desc.copy.money_value_multiplier = 1.5
	else
		desc.copy = {money_value_multiplier=1.5}
	end

	-- adjust difficulties
	-- Add randbosses to normal, they are half as frequent as rares
	desc = Birther:getBirthDescriptor("difficulty","Normal")
	if desc.game_state then
		desc.game_state.default_random_boss_chance = 50
	else
		desc.game_state = { default_random_boss_chance = 50 }
	end
	desc.desc =
	{
		"#GOLD##{bold}#Normal mode#WHITE##{normal}#",
		"Provides the normal level of challenges.",
		"Stairs can not be used for 2 turns after a kill.",
		"Random bosses appear on occasion.",
	}

	-- And Nightmare, again half as frequent as rares
	desc = Birther:getBirthDescriptor("difficulty","Nightmare")
	if desc.game_state then
		desc.game_state.default_random_boss_chance = 30
	else
		desc.game_state = { default_random_boss_chance = 30 }
	end
	desc.desc = {
		"#GOLD##{bold}#Nightmare mode#WHITE##{normal}#",
		"Not particularly unfair game setting",
		"All zone levels increased by 35%",
		"All creature talent levels increased by 30%",
		"Rare creatures and random bosses are slightly more frequent",
		"Stairs can not be used for 3 turns after a kill.",
		"Player can earn Nightmare version of achievements if also playing in Roguelike or Adventure permadeath mode.",
	}

	-- Only change is to description (zone level change is handled elsewhere)
	desc = Birther:getBirthDescriptor("difficulty","Insane")
	desc.desc = {
		"#GOLD##{bold}#Insane mode#WHITE##{normal}#",
		"Similar rules to Nightmare, but with more random bosses!",
		"All zone levels increased by 35% + 1",
		"All creature talent levels increased by 50%",
		"Rare creatures and random bosses are far more frequent",
		"Nonrandom bosses will have randomly selected talents",
		"All enemies have 20% more life",
		"Stairs can not be used for 5 turns after a kill.",
		"Player can earn Insane version of achievements if also playing in Roguelike or Adventure permadeath mode.",
	}

	-- make talent changes
	require("engine.interface.ActorTalents"):loadDefinition("/data-qt-zone-overhaul/talentChanges.lua")
end)

class:bindHook("Entity:loadList", function(self, data)
	local loadIfNot = function(f)
		if data.loaded[f] then return end
		self:loadList(f, data.no_default, data.res, data.mod, data.loaded)
	end
	-- No location restrictions on artifacts
	if data.file == "/data/general/objects/world-artifacts.lua" then
		loadIfNot("/data/general/objects/world-artifacts-maj-eyal.lua")
		loadIfNot("/data/general/objects/world-artifacts-far-east.lua")
		loadIfNot("/data/general/objects/boss-artifacts-maj-eyal.lua")
		loadIfNot("/data/general/objects/boss-artifacts-far-east.lua")
		loadIfNot("/data-qt-zone-overhaul/world-artifacts.lua")
	end

	local tier1NpcFiles = {-- remove specific artifacts from some t1 bosses (should probably do all of them but some of them are equipment lol)
		["/data/zones/heart-gloom/npcs.lua"] = true,
		--["/data/zones/norgos-lair/npcs.lua"] = true,
		["/data/zones/rhaloren-camp/npcs.lua"] = true,
		--["/data/zones/ruins-kor-pul/npcs.lua"] = true,
		["/data/zones/scintillating-caves/npcs.lua"] = true,
		--["/data/zones/trollmire/npcs.lua"] = true,
	}
--[[	local orcNpcFiles = {
		["/data/zones/gorbat-pride/npcs.lua"] = true,
		["/data/zones/grushnak-pride/npcs.lua"] = true,
		["/data/zones/rak-shor-pride/npcs.lua"] = true,
		["/data/zones/vor-pride/npcs.lua"] = true,
	}]]
	if tier1NpcFiles[data.file] then -- remove specific artifacts from some t1 bosses. remember we removed backup guardians so dont worry about those		
		for _,obj in pairs(data.res) do
			if type(obj) == "table" then
				for k,v in pairs(obj) do
					if type(v) == "table" and v.__resolver then
						if v.__resolver == "drops" then 
						if v[1] and v[1][1] and v[1][1].random_art_replace then
							v[1][1].defined = nil
							v[1][1].random_art_replace = nil
							v[1][1].unique = true
							v[1][1].not_properties = {"lore"}
						end
						end
					end
				end
			end
		end
-- Removes charred scar quest from orc npcs, works but not currently needed since we overload them anyway
--[[
	elseif orcNpcFiles[data.file] then -- removed charred scar quest from these guys; we deal with high peak in its zone.lua overload
		local orcs = {
			["GORBAT"] = function(self, who)
				game.player:resolveSource():setQuestStatus("orc-pride", engine.Quest.COMPLETED, "gorbat")
			end,
			["GRUSHNAK"] = function(self, who)
				game.player:resolveSource():setQuestStatus("orc-pride", engine.Quest.COMPLETED, "grushnak")
			end,
			["RAK_SHOR"] = function(self, who)
				game.player:resolveSource():setQuestStatus("orc-pride", engine.Quest.COMPLETED, "rak-shor")
			end,
			["VOR"] = function(self, who)
				game.player:resolveSource():setQuestStatus("orc-pride", engine.Quest.COMPLETED, "vor")
			end,
		}
		for _,obj in pairs(data.res) do
			if type(obj) == "table" then
				if orcs[obj.define_as] then
					obj.on_die = orcs[obj.define_as]
				end
			end
		end
]]
	elseif data.file == "/data/zones/reknor/grids.lua" then -- Change farportal destination
		for _,obj in pairs(data.res) do
			if type(obj) == "table" then
				if obj.define_as == "FAR_EAST_PORTAL" or obj.define_as == "CFAR_EAST_PORTAL" then
					obj.orb_portal.change_zone = "wilderness"
					obj.orb_portal.after_zone_teleport = nil
					obj.orb_portal.message = "#VIOLET#You enter the swirling portal and in the blink of an eye you set foot in an unfamiliar place, with no trace of the portal..."
				end
			end
		end
	elseif data.file == "/data/general/encounters/maj-eyal.lua" or data.file == "/data/general/encounters/maj-eyal-npcs.lua" or data.file == "/data/general/encounters/fareast-npcs.lua" or data.file == "/data/general/encounters/fareast.lua" then
		local removeEncounters = {
			["Ruined Dungeon"]=true,
			["Cursed Village"]=true,
			["Ring of Blood"]=true,
			["Shadow Crypt"]=true,
			["Allied Kingdoms human patrol"]=true,
			["Allied Kingdoms halfling patrol"]=true,
			["adventurers party"]=true,
			["ziguranth patrol"]=true,
			["Sun Paladins patrol"]=true,
			["Anorithil patrol"]=true,
			["Orcs patrol"]=true,
			["Underwater Cave"]=true,
			["Ancient Elven Ruins"]=true,
			["Agrimley the Hermit"]=true,
		}
		for _,obj in pairs(data.res) do
			if type(obj) == "table" then
				if removeEncounters[obj.name] then
					-- There's probably a better way to do this. We "remove" them by
					-- making them trigger immediately and do nothing...
					if obj.type == "patrol" or obj.type == "hostile" then
						obj.type = "harmless"
						obj.subtype = "special"
						obj.unique = true
						obj.immediate = {"world-encounter", "maj-eyal"}
						obj.rarity = nil
					end
					obj.on_encounter = function() return true end
				end
			end
		end
	elseif data.file == "/data/zones/wilderness/grids.lua" then
		-- cut zones that aren't encounters
		for _,obj in pairs(data.res) do
			if type(obj) == "table" then
				if obj.define_as == "TOWN_SHATUR" or obj.define_as == "TOWN_ELVALA" or obj.define_as == "TOWN_DERTH" or obj.define_as == "VOR_PRIDE" or obj.define_as == "UNREMARKABLE_CAVE" then
					obj.name = "plains"
					obj.image = "terrain/grass_worldmap/grass_main_01.png"
					obj.color = colors.LIGHT_GREEN
					obj.add_mos = nil
					obj.change_level = nil
					obj.glow = nil
					obj.display = '.'
					obj.notice = nil
					obj.add_displays = nil
					obj.nice_tiler = { method="replace", base={"PLAINS_PATCH", 70, 1, 14}}
					obj.back_color = {r=44,g=95,b=43}
				elseif obj.define_as == "SANDWORM_LAIR" then
					obj.name = "pile of sand"
					obj.image = "terrain/sandfloor.png"
					obj.color = {r=203,g=189,b=72}
					obj.add_mos = nil
					obj.change_level_check = function() require("engine.ui.Dialog"):simplePopup("Pile of sand", "If there were ever any sand tunnels here, they must have collapsed long ago.") return true end
				elseif obj.define_as == "GORBAT_PRIDE" then
					obj.name = "desert"
					obj.image = "terrain/sandfloor.png"
					obj.color = {r=203,g=189,b=72}
					obj.add_mos = nil
					obj.change_level = nil
					obj.glow = nil
					obj.display = '.'
					obj.notice = nil
				elseif obj.define_as == "RAK_SHOR_PRIDE" then
					obj.name = "Entrance to Rak'Vor Pride bastion"
				elseif obj.define_as == "GRUSHNAK_PRIDE" then
					obj.name = "Entrance to Grushbat Pride bastion"
				elseif obj.define_as == "TEMPEST_PEAK" then
					obj.change_level_check = nil
				elseif obj.define_as == "REL_TUNNEL" then
					obj.change_level = 3
				end
			end
		end
	elseif data.file == "/data/zones/daikara/npcs.lua" then
		for _,obj in pairs(data.res) do
			if type(obj) == "table" then
				if obj.define_as == "RANTHA_THE_WORM" or obj.define_as == "VARSHA_THE_WRITHING" then
					-- XXX: The original gold drops actually get cut off, so increasing the inventory size,
					-- while required to add the sandqueen heart without even worse hackery, will also increase
					-- the amount of gold dropped a bit. I don't know if it getting cut off was intentional in
					-- the first place, it certainly seems like it shouldn't be! Ah well, this addon removes
					-- far more gold than that elsewhere anyway.
					obj.body = { INVEN = 20, MAINHAND=1, OFFHAND=1, BODY=1 }
					for _,inv in ipairs(obj.inven) do
						if inv.name == "INVEN" then inv.max = 20 break end
					end
					table.insert(obj,resolvers.drops{chance=100, nb=1, {defined="SANDQUEEN_HEART"}})
					obj.allow_infinite_dungeon = nil -- XXX: this is not ideal
				end
			end
		end
	elseif data.file == "/data/zones/daikara/objects.lua" then
		self:loadList("/data-qt-zone-overhaul/daikara-objects.lua", data.no_default, data.res, data.mod, data.loaded) -- sandworm heart
	elseif data.file == "/data/zones/vor-armoury/npcs.lua" then
		for _,obj in pairs(data.res) do
			if type(obj) == "table" then
				if obj.define_as == "OVERPOWERED_WYRM" then
					obj.exp_worth = 0 -- don't give xp
					obj.make_escort = {} -- no drakes
				end
			end
		end
	elseif data.file == "/data/zones/vor-armoury/objects.lua" then
		self:loadList("/data-qt-zone-overhaul/ruby-eye.lua", data.no_default, data.res, data.mod, data.loaded)
	elseif data.file == "/data/zones/slime-tunnels/grids.lua" then
		for _,obj in pairs(data.res) do
			if type(obj) == "table" then
				if obj.change_zone and obj.change_zone == "grushnak-pride" then
					obj.name = "exit to Grushbat Pride"
				end
			end
		end
	elseif data.file == "/data/zones/lake-nur/grids.lua" then
		-- we trimmed old forest levels, so we have to update this
		for _,obj in pairs(data.res) do
			if type(obj) == "table" then
				if obj.change_zone and obj.change_zone == "old-forest" then
					obj.change_level = 3
				end
			end
		end
	end
end)
