name = "A new beginning"

tier1List = {
	{short_name="heart-gloom",name="the Heart of the Gloom"},
	{short_name="ruins-kor-pul",name="the ruins of Kor'Pul"},
	{short_name="norgos-lair",name="Norgos' Lair"},
	{short_name="rhaloren-camp",name="the Rhaloren camp"},
	{short_name="scintillating-caves",name="the Scintillating Caves"},
	{short_name="trollmire",name="the Trollmire"},
}

zonesEntered = 0

makeOnLevelLoads = function(self)
	for _,zone in ipairs(self.tier1List) do
		local f = function() game.player:setQuestStatus("qt-tier1-zones", engine.Quest.COMPLETED, game.zone.short_name) end
		-- UGH: we do it on both levels because of celestial starting quest putting you on level 2...
		game:onLevelLoad(zone.short_name.."-1",f)
		game:onLevelLoad(zone.short_name.."-2",f)
	end
end

desc = function(self, who)
	local desc = {}
	desc[#desc+1] = "Across Maj'Eyal are places inhabited by evil - and treasure. But you don't have time to visit all of them."
	desc[#desc+1] = "You may enter only two of the following zones:"

	for _,zone in ipairs(self.tier1List) do
		if self:isCompleted(zone.short_name) then
			desc[#desc+1] = string.format("#LIGHT_GREEN#* You have visited %s.#WHITE#",zone.name)
		elseif self.zonesEntered < 2 then
			desc[#desc+1] = string.format("#SLATE#* You have not visited %s.#WHITE#",zone.name)
		else
			desc[#desc+1] = string.format("#SLATE#* You elected not to visit %s.#WHITE#",zone.name)
		end
	end

	return table.concat(desc, "\n")
end

on_status_change = function(self, who, status, sub)
	if sub then
		self.zonesEntered = self.zonesEntered+1
		if self.zonesEntered == 2 then
			who:setQuestStatus(self.id, engine.Quest.DONE)

			-- Complete any starting quests that might have been made impossible (e.g. shalore visited two zones that weren't Rhaloren Camp),
			-- so we don't have permanent junk on the quest screen.
			local t1StartQuests = {"start-allied","start-thaloren","start-shaloren"}
			for _,q in pairs(t1StartQuests) do
				if who:hasQuest(q) then who:setQuestStatus(q,self.DONE) end
			end

			-- Remove entrances.
			game:onLevelLoad("wilderness-1",function(zone,level)
				local q = game.player:hasQuest("qt-tier1-zones")
				if q then
					-- Get a table of zone entrances that we'll remove.
					local ztab = {}
					for _,z in ipairs(q.tier1List) do
						if not q:isCompleted(z.short_name) then
							ztab[z.short_name] = true
						end
					end

					-- Find and remove them.
					for x=0,game.level.map.w-1 do
						for y=0,game.level.map.h-1 do
							local grid = game.level.map:checkAllEntities(x,y,"change_zone")
							if grid and ztab[grid] then
								local g = game.zone:makeEntityByName(level, "terrain", "PLAINS")
								g:resolve() g:resolve(nil, true)
								game.zone:addEntity(level, g, "terrain", x, y)
								game.nicer_tiles:updateAround(game.level, x, y)							
							end
						end
					end
				end
			end)
		end
	end
end

-- HACK: make tempest peak entrance here...
on_grant = function(self, who)
	game:onLevelLoad("wilderness-1", function(zone, level)
		local g = game.zone:makeEntityByName(level, "terrain", "TEMPEST_PEAK")
		local spot = level:pickSpot{type="zone-pop", subtype="tempest-peak"}
		game.zone:addEntity(level, g, "terrain", spot.x, spot.y)
		game.nicer_tiles:updateAround(game.level, spot.x, spot.y)
		game.state:locationRevealAround(spot.x, spot.y)
	end)
end
