load("/data/general/npcs/orc.lua", rarity(3))
load("/data/general/npcs/orc-gorbat.lua", rarity(0))
load("/data/general/npcs/orc-grushnak.lua", rarity(0))
load("/data/general/npcs/cold-drake.lua", rarity(1))
load("/data/general/npcs/storm-drake.lua", rarity(1))
load("/data/general/npcs/fire-drake.lua", rarity(1))
load("/data/general/npcs/venom-drake.lua", rarity(1))
load("/data/general/npcs/multihued-drake.lua", rarity(3))

load("/data/general/npcs/all.lua", rarity(4, 35))

local Talents = require("engine.interface.ActorTalents")

newEntity{ base="BASE_NPC_ORC_GRUSHNAK", define_as = "GRUSHNAK",
	allow_infinite_dungeon = true,
	name = "Grushnak, Battlemaster of the Pride", color=colors.VIOLET, unique = true,
	desc = [[An old orc, covered in battle scars, he looks fierce and very, very, dangerous.]],
	killer_message = "and mounted on the barracks wall",
	level_range = {45, nil}, exp_worth = 1,
	rank = 5,
	max_life = 700, life_rating = 25, fixed_rating = true,
	infravision = 10,
	stats = { str=15, dex=10, cun=12, wil=45, mag=16, con=14 },
	move_others=true,

	instakill_immune = 1,
	stun_immune = 1,
	combat_armor = 10, combat_def = 10,
	stamina_regen = 40,

	open_door = true,

	autolevel = "warrior",
	ai = "tactical", ai_state = { talent_in=1, ai_move="move_astar", },
	ai_tactic = resolvers.tactic"melee",
	resolvers.inscriptions(4, "infusion"),

	body = { INVEN = 10, MAINHAND=1, OFFHAND=1, BODY=1, HEAD=1, FEET=1, FINGER=2, NECK=1, TOOL=1 },

	resolvers.equip{
		{type="weapon", subtype="waraxe", force_drop=true, tome_drops="boss", autoreq=true},
		{type="armor", subtype="shield", force_drop=true, tome_drops="boss", autoreq=true},
		{type="armor", subtype="massive", force_drop=true, tome_drops="boss", autoreq=true},
		{type="armor", subtype="head", force_drop=true, tome_drops="boss", autoreq=true},
		{type="armor", subtype="feet", force_drop=true, tome_drops="boss", autoreq=true},
		{type="charm", subtype="totem"},
--		Commented because this can generate rings of invis or amulets of telepathy and drain the life of the boss
--		{type="jewelry", subtype="amulet", force_drop=true, tome_drops="boss", autoreq=true},
--		{type="jewelry", subtype="ring", force_drop=true, tome_drops="boss", autoreq=true},
		{type="jewelry", subtype="ring", defined="PRIDE_GLORY", random_art_replace={chance=75}, autoreq=true},
	},
	resolvers.drops{chance=100, nb=1, {defined="ORB_DESTRUCTION"} },
	resolvers.drops{chance=100, nb=5, {tome_drops="boss"} },
	resolvers.drops{chance=100, nb=1, {defined="NOTE_LORE"} },

	make_escort = {
		{type="orc", no_subescort=true, number=resolvers.mbonus(6, 5)},
	},

	resolvers.talents{
		[Talents.T_WEAPON_COMBAT]={base=5, every=10, max=7},
		[Talents.T_ARMOUR_TRAINING]={base=5, every=10, max=7},
		[Talents.T_WEAPONS_MASTERY]={base=5, every=10, max=7},
		[Talents.T_RUSH]={base=5, every=6, max=7},
		[Talents.T_BATTLE_CALL]={base=5, every=6, max=7},
		[Talents.T_SHIELD_PUMMEL]={base=4, every=6, max=6},
		[Talents.T_OVERPOWER]={base=5, every=6, max=7},
		[Talents.T_ASSAULT]={base=3, every=6, max=6},
		[Talents.T_SHIELD_EXPERTISE]={base=5, every=6, max=7},
		[Talents.T_BATTLE_SHOUT]={base=3, every=6, max=6},
		[Talents.T_SHIELD_WALL]={base=5, every=6, max=7},
		[Talents.T_SHATTERING_SHOUT]={base=5, every=6, max=7},
		[Talents.T_BATTLE_CRY]={base=5, every=6, max=7},
		[Talents.T_ONSLAUGHT]={base=5, every=6, max=7},
		[Talents.T_SECOND_WIND]={base=5, every=6, max=7},
		[Talents.T_JUGGERNAUT]={base=5, every=6, max=7},
		[Talents.T_UNSTOPPABLE]={base=5, every=6, max=7},
		[Talents.T_MORTAL_TERROR]={base=3, every=6, max=6},
		[Talents.T_BLOODBATH]={base=5, every=6, max=7},
		[Talents.T_ETERNAL_GUARD]=1,
		[Talents.T_UNBREAKABLE_WILL]=1,
		[Talents.T_GIANT_LEAP]=1,
	},
	resolvers.sustains_at_birth(),

	on_die = function(self, who)
		game.player:resolveSource():setQuestStatus("orc-pride", engine.Quest.COMPLETED, "grushnak")
	end,
}

newEntity{ base="BASE_NPC_ORC_GORBAT", define_as = "GORBAT",
	allow_infinite_dungeon = true,
	name = "Gorbat, Supreme Wyrmic of the Pride", color=colors.VIOLET, unique = true,
	resolvers.nice_tile{image="invis.png", add_mos = {{image="npc/humanoid_orc_gorbat__supreme_wyrmic_of_the_pride.png", display_h=2, display_y=-1}}},
	desc = [[An orc with scaly skin, claws and a pair of small wings on his back.]],
	killer_message = "and fed to the hatchlings",
	level_range = {40, nil}, exp_worth = 1,
	rank = 5,
	max_life = 250, life_rating = 29, fixed_rating = true,
	infravision = 10,
	stats = { str=12, dex=10, cun=100, mag=21, con=14 },
	move_others=true,

	combat_armor = 10, combat_def = 10,

	open_door = true,

	autolevel = "wyrmic",
	ai = "tactical", ai_state = { talent_in=1, ai_move="move_astar", },
	resolvers.inscriptions(4, "infusion"),

	body = { INVEN = 10, MAINHAND=1, OFFHAND=1, BODY=1, HEAD=1, TOOL=1 },

	resolvers.equip{
		{type="weapon", subtype="greatmaul", force_drop=true, tome_drops="boss", autoreq=true},
		{type="armor", subtype="light", defined="CHROMATIC_HARNESS", random_art_replace={chance=75}, autoreq=true},
		{type="charm", subtype="totem"}
	},
	resolvers.drops{chance=100, nb=1, {defined="ORB_DRAGON"} },
	resolvers.drops{chance=100, nb=5, {tome_drops="boss"} },
	resolvers.drops{chance=100, nb=1, {defined="NOTE_LORE_GORBAT"} },

	talent_cd_reduction={[Talents.T_ICE_BREATH]=3, [Talents.T_FIRE_BREATH]=3, [Talents.T_SAND_BREATH]=3, },
	equilibrium_regen = -10,

	resolvers.talents{
		[Talents.T_NATURE_TOUCH]={base=5, every=6, max=7},

		[Talents.T_ICE_BREATH]={base=10, every=6, max=12},
		[Talents.T_FIRE_BREATH]={base=10, every=6, max=12},
		[Talents.T_SAND_BREATH]={base=10, every=6, max=12},

		[Talents.T_ICY_SKIN]={base=5, every=6, max=7},
		[Talents.T_ICE_CLAW]={base=7, every=6, max=10},

		[Talents.T_BELLOWING_ROAR]={base=7, every=6, max=10},
		[Talents.T_WING_BUFFET]={base=5, every=6, max=7},
		[Talents.T_ACIDIC_SKIN]={base=7, every=6, max=10},

		[Talents.T_RIMEBARK]={base=7, every=6, max=10},
		[Talents.T_RITCH_FLAMESPITTER]={base=10, every=6, max=12},
		[Talents.T_RESILIENCE]={base=5, every=6, max=7},
		[Talents.T_MASTER_SUMMONER]={base=5, every=6, max=7},
		[Talents.T_WILD_SUMMON]={base=5, every=6, max=7},

		[Talents.T_HOWL]={base=5, every=6, max=7},

		[Talents.T_DISARM]={base=5, every=6, max=7},
		[Talents.T_WEAPON_COMBAT]={base=3, every=8, max=5},
		[Talents.T_WEAPONS_MASTERY]={base=3, every=8, max=5},

		[Talents.T_ARMOUR_TRAINING]=3,

		[Talents.T_SPELL_FEEDBACK]=1,
		[Talents.T_SPINE_OF_THE_WORLD]=1,
		[Talents.T_MASSIVE_BLOW]=1,
		[Talents.T_BLIGHTED_SUMMONING]=1,
	},
	resolvers.sustains_at_birth(),

	on_die = function(self, who)
		game.player:resolveSource():setQuestStatus("orc-pride", engine.Quest.COMPLETED, "gorbat")
	end,
}
