-- ToME - Tales of Maj'Eyal
-- Copyright (C) 2009 - 2015 Nicolas Casalini
--
-- This program is free software: you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program.  If not, see <http://www.gnu.org/licenses/>.
--
-- Nicolas Casalini "DarkGod"
-- darkgod@te4.org

return {
	name = "Temporal Rift",
	display_name = function(x, y)
		if game.level.level == 1 then return "Temporal Rift: Daikara"
		elseif game.level.level == 2 then return "Temporal Rift: Lake of Nur"
		end
		return "Temporal Rift"
	end,
	variable_zone_name = true,
	level_range = {20, 20},
	level_scheme = "player",
	max_level = 2,
	decay = {300, 800},
	actor_adjust_level = function(zone, level, e) return zone.base_level + e:getRankLevelAdjust() + level.level-1 + rng.range(-1,2) end,
	width = 60, height = 25,
--	all_remembered = true,
	all_lited = true,
	no_worldport = true,
	persistent = "zone",
	min_material_level = 2,
	max_material_level = 3,
	effects = {"EFF_ZONE_AURA_OUT_OF_TIME"},
	generator =  {
	},
	color_shown = {0.7, 0.6, 0.8, 1},
	color_obscure = {0.7*0.6, 0.6*0.6, 0.8*0.6, 0.6},
	ambient_music = "Through the Dark Portal.ogg",
	levels =
	{
		[1] = {
			width = 50, height = 50,
			generator = {
			map = {
				class = "engine.generator.map.Roomer",
				nb_rooms = 10,
				edge_entrances = {2,8},
				rooms = {"forest_clearing","rocky_snowy_trees"},
				['.'] = "ROCKY_GROUND",
				['T'] = "ROCKY_SNOWY_TREE",
				['#'] = "MOUNTAIN_WALL",
				up = "ROCKY_GROUND",
				down = "ROCKY_GROUND",
				door = "ROCKY_GROUND",
			},
			actor = {
				class = "mod.class.generator.actor.Random",
				filters = {{type="horror", subtype="temporal",}},
				nb_npc = {15, 25},
			},
		} },
		[2] = {
			width = 50, height = 50,
			generator = {
			map = {
				class = "engine.generator.map.Static",
				map = "zones/lake-nur",
			},
			actor = {
				class = "mod.class.generator.actor.Random",
				nb_npc = {0, 0},
			},
		} },
	},
	on_enter = function(lev, old_lev, newzone)
		game.player:attr("temporal_touched", 1)

		local Dialog = require("engine.ui.Dialog")
		if lev == 1 and not game.level.shown_warning then
			Dialog:simplePopup("Temporal Rift", "As you pass the rift you see what seems to be the Daikara mountains, yet they are not.")
			game.level.shown_warning = true
			require("mod.class.generator.actor.Random").new(game.zone, game.level.map, game.level, {}):generateGuardian("ABOMINATION_RANTHA")
		elseif lev == 2 and not game.level.shown_warning then
			Dialog:simplePopup("Temporal Rift", "The peace of this place has been disturbed.")
			game.level.shown_warning = true

			local m1 = game.zone:makeEntityByName(game.level, "actor", "CHRONOLITH_TWIN")
			game.zone:addEntity(game.level, m1, "actor", 26, 8)
			local m2 = game.zone:makeEntityByName(game.level, "actor", "CHRONOLITH_CLONE")
			game.zone:addEntity(game.level, m2, "actor", 29, 8)
			m1.brother = m2
			m2.brother = m1
		end
	end,

	portal_next = function(npc)
		local g = game.zone:makeEntityByName(game.level, "terrain", "RIFT")
		local oe = game.level.map(npc.x, npc.y, engine.Map.TERRAIN)
		if oe:attr("temporary") and oe.old_feat then 
			oe.old_feat = g
		else
			game.zone:addEntity(game.level, g, "terrain", npc.x, npc.y)
		end
	end,

	foreground = function(level, x, y, nb_keyframes)
		if not config.settings.tome.weather_effects or not level.foreground_particle then return end
		level.foreground_particle.ps:toScreen(x, y, true, 1)
	end,
}
